@@ -1,5 +1,6 @@
 /*
  *  Copyright (C) 2001,2002,2003 Nikos Mavroyanopoulos
+ *  Copyright (C) 2004 Free Software Foundation
  *
  *  This file is part of GNUTLS.
  *
@@ -326,14 +327,9 @@ void gnutls_certificate_server_set_select_function(gnutls_session session,
   * to be used in the handshake.
   * The callback's function prototype is:
   * int (*callback)(gnutls_session, const gnutls_datum* req_ca_dn, int nreqs, 
-  * gnutls_datum **cert, unsigned int *ncerts, gnutls_key* key);
+  * gnutls_pk_algorithm* pk_algos, int pk_algos_length, gnutls_retr_st st);
   *
-  * @cert should contain @ncerts gnutls_datum structures which hold
-  * the raw certificates (DER for X.509 or binary for OpenPGP), of the
-  * client. Those should be allocated with gnutls_malloc(). The certificate
-  * type to be sent should be obtained using gnutls_certificate_type_get();
-  *
-  * @key should contain a private key.
+  * @st should contain the certificates and private keys.
   *
   * @req_ca_cert, is only used in X.509 certificates. 
   * Contains a list with the CA names that the server considers trusted. 
@@ -341,6 +337,9 @@ void gnutls_certificate_server_set_select_function(gnutls_session session,
   * by one of these CAs. These names are DER encoded. To get a more
   * meaningful value use the function gnutls_x509_rdn_get().
   *
+  * @pk_algos, contains a list with server's acceptable signature algorithms.
+  * The certificate returned should support the server's given algorithms.
+  *
   * If the callback function is provided then gnutls will call it, in the
   * handshake, after the certificate request message has been received.
   *
@@ -362,15 +361,10 @@ void gnutls_certificate_client_set_retrieve_function(gnutls_certificate_credenti
   * This function sets a callback to be called in order to retrieve the certificate
   * to be used in the handshake.
   * The callback's function prototype is:
-  * int (*callback)(gnutls_session, gnutls_datum **cert, unsigned int *ncerts
-  * gnutls_key* key);
+  * int (*callback)(gnutls_session, const gnutls_datum* req_ca_dn, int nreqs, 
+  * gnutls_pk_algorithm* pk_algos, int pk_algos_length, gnutls_retr_st st);
   *
-  * @cert should contain @ncerts gnutls_datum structures which hold
-  * the raw certificates (DER for X.509 or binary for OpenPGP), of the
-  * server. Those should be allocated with gnutls_malloc(). The certificate
-  * type to be sent should be obtained using gnutls_certificate_type_get();
-  *
-  * @key should contain a private key.
+  * @st should contain the certificates and private keys.
   *
   * If the callback function is provided then gnutls will call it, in the
   * handshake, after the certificate request message has been received.
@@ -389,8 +383,8 @@ void gnutls_certificate_server_set_retrieve_function(gnutls_certificate_credenti
 /* These are set by the gnutls_extra library's initialization function.
  */
 
-OPENPGP_KEY_CREATION_TIME_FUNC _E_gnutls_openpgp_extract_key_creation_time = NULL;
-OPENPGP_KEY_EXPIRATION_TIME_FUNC _E_gnutls_openpgp_extract_key_expiration_time = NULL;
+OPENPGP_KEY_CREATION_TIME_FUNC _E_gnutls_openpgp_get_raw_key_creation_time = NULL;
+OPENPGP_KEY_EXPIRATION_TIME_FUNC _E_gnutls_openpgp_get_raw_key_expiration_time = NULL;
 OPENPGP_VERIFY_KEY_FUNC _E_gnutls_openpgp_verify_key = NULL;
 
 /*-
@@ -516,12 +510,12 @@ time_t gnutls_certificate_expiration_time_peers(gnutls_session session)
 
 	switch( gnutls_certificate_type_get( session)) {
 		case GNUTLS_CRT_X509:
-			return gnutls_x509_extract_certificate_expiration_time(
+			return _gnutls_x509_get_raw_crt_expiration_time(
 				&info->raw_certificate_list[0]);
 		case GNUTLS_CRT_OPENPGP:
-			if (_E_gnutls_openpgp_extract_key_expiration_time==NULL)
+			if (_E_gnutls_openpgp_get_raw_key_expiration_time==NULL)
 				return (time_t)-1;
-			return _E_gnutls_openpgp_extract_key_expiration_time(
+			return _E_gnutls_openpgp_get_raw_key_expiration_time(
 				&info->raw_certificate_list[0]);
 		default:
 			return (time_t)-1;
@@ -556,12 +550,12 @@ time_t gnutls_certificate_activation_time_peers(gnutls_session session)
 
 	switch( gnutls_certificate_type_get( session)) {
 		case GNUTLS_CRT_X509:
-			return gnutls_x509_extract_certificate_activation_time(
+			return _gnutls_x509_get_raw_crt_activation_time(
 				&info->raw_certificate_list[0]);
 		case GNUTLS_CRT_OPENPGP:
-			if (_E_gnutls_openpgp_extract_key_creation_time==NULL)
+			if (_E_gnutls_openpgp_get_raw_key_creation_time==NULL)
 				return (time_t)-1;
-			return _E_gnutls_openpgp_extract_key_creation_time(
+			return _E_gnutls_openpgp_get_raw_key_creation_time(
 				&info->raw_certificate_list[0]);
 		default:
 			return (time_t)-1;
