@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2000 Nikos Mavroyanopoulos
+ * Copyright (C) 2004 Free Software Foundation
  *
  * This file is part of GNUTLS.
  *
@@ -222,13 +223,10 @@ int gnutls_certificate_type_set_priority(gnutls_session session,
   * the appropriate functions.
   *
   * The order is TLS1, SSL3 for protocols.
-  * GNUTLS_KX_RSA, GNUTLS_KX_DHE_DSS, GNUTLS_KX_DHE_RSA for key exchange 
-  * algorithms.
-  * GNUTLS_MAC_SHA, GNUTLS_MAC_MD5 for MAC algorithms.
-  * GNUTLS_CIPHER_AES_256_CBC, 
-  * GNUTLS_CIPHER_AES_128_CBC, 
-  * and GNUTLS_CIPHER_3DES_CBC, 
-  * GNUTLS_CIPHER_ARCFOUR_128 for ciphers.
+  * RSA, DHE_DSS, DHE_RSA for key exchange 
+  * algorithms. SHA, MD5 and RIPEMD160 for MAC algorithms.
+  * AES_256_CBC, AES_128_CBC, 3DES_CBC, 
+  * and ARCFOUR_128 for ciphers.
   *
   **/
 int gnutls_set_default_priority(gnutls_session session)
@@ -243,7 +241,7 @@ int gnutls_set_default_priority(gnutls_session session)
 	};
 	static const int comp_priority[] = { GNUTLS_COMP_NULL, 0 };
 	static const int mac_priority[] =
-	    { GNUTLS_MAC_SHA, GNUTLS_MAC_MD5, 0 };
+	    { GNUTLS_MAC_SHA, GNUTLS_MAC_MD5, GNUTLS_MAC_RMD160, 0 };
 
 	gnutls_cipher_set_priority(session, cipher_priority);
 	gnutls_compression_set_priority(session, comp_priority);
@@ -261,12 +259,11 @@ int gnutls_set_default_priority(gnutls_session session)
   * Sets some default priority on the ciphers, key exchange methods, macs
   * and compression methods. This is to avoid using the gnutls_*_priority() functions, if
   * these defaults are ok. This function also includes weak algorithms.
-  * The order is TLS1, SSL3 for protocols,  GNUTLS_KX_DHE_DSS, GNUTLS_KX_RSA, 
-  * GNUTLS_KX_DHE_RSA, GNUTLS_KX_RSA_EXPORT for key exchange algorithms.
-  * GNUTLS_MAC_SHA, GNUTLS_MAC_MD5 for MAC algorithms,
-  * GNUTLS_CIPHER_AES_256_CBC, GNUTLS_CIPHER_AES_128_CBC, 
-  * and GNUTLS_CIPHER_3DES_CBC, GNUTLS_CIPHER_ARCFOUR_128, 
-  * GNUTLS_CIPHER_ARCFOUR_40 for ciphers.
+  * The order is TLS1, SSL3 for protocols,  RSA, DHE_DSS, 
+  * DHE_RSA, RSA_EXPORT for key exchange algorithms.
+  * SHA, MD5, RIPEMD160 for MAC algorithms,
+  * AES_256_CBC, AES_128_CBC, 
+  * and 3DES_CBC, ARCFOUR_128, ARCFOUR_40 for ciphers.
   *
   **/
 int gnutls_set_default_export_priority(gnutls_session session)
@@ -285,7 +282,7 @@ int gnutls_set_default_export_priority(gnutls_session session)
 	};
 	static const int comp_priority[] = { GNUTLS_COMP_NULL, 0 };
 	static const int mac_priority[] =
-	    { GNUTLS_MAC_SHA, GNUTLS_MAC_MD5, 0 };
+	    { GNUTLS_MAC_SHA, GNUTLS_MAC_MD5, GNUTLS_MAC_RMD160, 0 };
 
 	gnutls_cipher_set_priority(session, cipher_priority);
 	gnutls_compression_set_priority(session, comp_priority);
