@@ -341,11 +341,12 @@ gnutls_x509_crt generate_certificate( gnutls_x509_privkey *ret_key)
 
 
 	serial = read_int( "Enter the certificate's serial number (decimal): ");
-	buffer[2] = serial & 0xff;
-	buffer[1] = (serial >> 8) & 0xff;
-	buffer[0] = (serial >> 16) & 0xff;
+	buffer[3] = serial & 0xff;
+	buffer[2] = (serial >> 8) & 0xff;
+	buffer[1] = (serial >> 16) & 0xff;
+	buffer[0] = 0;
 
-	result = gnutls_x509_crt_set_serial( crt, buffer, 3);
+	result = gnutls_x509_crt_set_serial( crt, buffer, 4);
 	if (result < 0) {
 		fprintf(stderr, "serial: %s\n", gnutls_strerror(result));
 		exit(1);
@@ -803,7 +804,7 @@ int ret;
 }
 
 
-const char* get_algorithm( int a) 
+const char* get_pk_algorithm( gnutls_pk_algorithm a) 
 {
 	switch (a) {
 		case GNUTLS_PK_RSA:
@@ -816,6 +817,23 @@ const char* get_algorithm( int a)
 	}
 }
 
+const char* get_sign_algorithm( gnutls_sign_algorithm a) 
+{
+	switch (a) {
+		case GNUTLS_SIGN_RSA_SHA:
+			return "RSA-SHA";
+		case GNUTLS_SIGN_RSA_MD5:
+			return "RSA-MD5";
+		case GNUTLS_SIGN_RSA_MD2:
+			return "RSA-MD2";
+		case GNUTLS_SIGN_DSA_SHA:
+			return "DSA-SHA";
+			break;
+		default:
+			return "UNKNOWN";
+	}
+}
+
 /* OIDs that are handled by the gnutls' functions.
  */
 static inline int known_oid( const char* oid)
@@ -919,7 +937,7 @@ static void print_certificate_info( gnutls_x509_crt crt, FILE* out, unsigned int
 		fprintf(out, "Signature Algorithm: ");
 		ret = gnutls_x509_crt_get_signature_algorithm(crt);
 		
-		cprint = get_algorithm( ret);
+		cprint = get_sign_algorithm( ret);
 		fprintf(out,  "%s\n", cprint);
 	}
 
@@ -939,7 +957,7 @@ static void print_certificate_info( gnutls_x509_crt crt, FILE* out, unsigned int
 	ret = gnutls_x509_crt_get_pk_algorithm(crt, NULL);
 	fprintf(out, "\tPublic Key Algorithm: ");
 
-	cprint = get_algorithm( ret);
+	cprint = get_pk_algorithm( ret);
 	fprintf(out,  "%s\n", cprint);
 
 
@@ -1164,7 +1182,7 @@ static void print_crl_info( gnutls_x509_crl crl, FILE* out, int all)
 		fprintf(out, "Signature Algorithm: ");
 		ret = gnutls_x509_crl_get_signature_algorithm(crl);
 
-		cprint = get_algorithm( ret);
+		cprint = get_sign_algorithm( ret);
 		fprintf(out,  "%s\n", cprint);
 	}
 
@@ -1281,7 +1299,7 @@ void privkey_info( void)
 	ret = gnutls_x509_privkey_get_pk_algorithm(key);
 	fprintf(outfile, "\tPublic Key Algorithm: ");
 
-	cprint = get_algorithm( ret);
+	cprint = get_pk_algorithm( ret);
 	fprintf(outfile,  "%s\n", cprint);
 
 
